import { defineStore } from "pinia";
import { ref } from "vue";
import _ from "underscore";
import type { LoginResult } from "@/types/user";
// 定义 Store
export const useMemberStore = defineStore(
  "member",
  () => {
    // 会员信息
    const profile = ref<LoginResult>({
      token: "",
      userInfo: {
        userName: "",
        factoryName: "",
      },
      menusList: [],
      menusNameList: [],
      err: null,
    });

    const mechanism = ref<any>({
      mechanismCode: "",
      mechanismName: "",
    });

    // 保存会员信息，登录时使用
    const setProfile = (val: any) => {
      profile.value = { ...profile.value, ...val };
      profile.value.menusNameList = _.pluck(val.menusList, "name");

      // 判断微信版本是否兼容小程序更新机制API
      if (uni.canIUse("getUpdateManager")) {
        const updateManager = uni.getUpdateManager();
        updateManager.onCheckForUpdate((res) => {
          if (res.hasUpdate) {
            updateManager.onUpdateReady(() => {
              uni.showModal({
                title: "更新提示",
                content: "新版本已更新, 是否应用",
                success: (res) => {
                  if (res.confirm) {
                    updateManager.applyUpdate();
                  }
                },
              });
            });
          }
        });

        updateManager.onUpdateFailed((err) => {
          uni.showModal({
            title: "新版本更新提示",
            content: "请删除当前小程序, 到微信搜索小程序, 重新打开",
            showCancel: false,
          });
        });
      } else {
        uni.showModal({
          title: "温馨提示",
          content: "当前微信版本过低，无法使用该功能，请升级到最新版本后重试",
          showCancel: false,
        });
      }
    };

    const setErr = (v: any) => {
      profile.value.err = v;
    };

    // 清理会员信息，退出时使用
    const clearProfile = () => {
      profile.value = {
        token: "",
        userInfo: {
          userName: "",
          factoryName: "",
        },
        menusList: [],
        menusNameList: [],
      };

      mechanism.value.mechanismCode = "";
      mechanism.value.mechanismName = "";
    };

    const setMechanism = (v: { mechanismCode: ""; mechanismName: "" }) => {
      mechanism.value = v;
    };

    // 记得 return
    return {
      profile,
      setProfile,
      setErr,
      clearProfile,
      mechanism,
      setMechanism,
    };
  },
  {
    // 配置持久化
    persist: {
      // 调整为兼容多端的API
      storage: {
        setItem(key, value) {
          uni.setStorageSync(key, value);
        },
        getItem(key) {
          return uni.getStorageSync(key);
        },
      },
    },
  }
);
